/*
 * Copyright (c) 2023-Present Jonathan MASSUCHETTI <jonathan.massuchetti@dappit.fr>.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import { hasOwn, invariant } from '@cbjsdev/shared';
export function queryIndexRowToFriendlyFormat(index) {
    invariant(index.using === 'fts');
    const friendly = {};
    if (hasOwn(index, 'bucket_id')) {
        friendly.bucketName = index.bucket_id;
        friendly.scopeName = index.scope_id;
        friendly.collectionName = index.keyspace_id;
    }
    else {
        friendly.bucketName = index.keyspace_id;
    }
    friendly.id = index.id;
    friendly.name = index.name;
    friendly.fields = index.index_key.map((field) => {
        if (field.startsWith('`') && field.endsWith('`')) {
            return field.substring(1, field.length - 1);
        }
        return field;
    });
    friendly.node = index.datastore_id;
    friendly.state = index.state;
    friendly.namespace = index.namespace_id;
    friendly.using = index.using;
    return friendly;
}
//# sourceMappingURL=utils.js.map