import { OneOf } from '@cbjsdev/shared';
export type QueryIndexes = QueryGsiIndex | QuerySearchIndex;
export type QueryGsiIndex = DiscriminatingPrimaryIndexProps & DiscriminatingKeyspaceProps & {
    datastore_id: string;
    id: string;
    /**
     * Index name.
     */
    name: string;
    namespace_id: string;
    state: 'online' | 'deferred' | (string & NonNullable<unknown>);
    using: 'gsi';
    metadata: {
        num_replica: number;
    };
};
/**
 * Search index as described by the Query service.
 */
export type QuerySearchIndex = DiscriminatingKeyspaceProps & {
    datastore_id: string;
    id: string;
    /**
     * Index name.
     */
    name: string;
    index_key: [string, ...string[]];
    namespace_id: string;
    state: 'online' | 'deferred' | (string & NonNullable<unknown>);
    using: 'fts';
};
type DiscriminatingPrimaryIndexProps = {
    is_primary: true;
    /**
     * Indexed fields.
     */
    index_key: [];
} | {
    is_primary: undefined;
    /**
     * Indexed fields.
     */
    index_key: [string, ...string[]];
};
type DiscriminatingKeyspaceProps = OneOf<[
    {
        /**
         * Bucket name.
         */
        keyspace_id: string;
    },
    {
        /**
         * Bucket name
         */
        bucket_id: string;
        /**
         * Scope name.
         */
        scope_id: string;
        /**
         * Collection name.
         */
        keyspace_id: string;
    }
]>;
export {};
